@@ -19,13 +19,14 @@ from Qt.QtCore import *
 from Qt.QtWidgets import *
 from Qt.QtGui import *
 
-from tpQtLib.core import base, qtutils
-from tpQtLib.widgets import grid
+import tpDcc
+from tpDcc.libs.python import python
+from tpDcc.libs.qt.core import base, qtutils
+from tpDcc.libs.qt.widgets import grid
 
 import artellapipe
 import artellapipe.register
 from artellapipe.core import defines
-from artellapipe.utils import resource
 
 LOGGER = logging.getLogger()
 
@@ -35,7 +36,7 @@ class AssetsViewer(grid.GridWidget, object):
     assetAdded = Signal(object)
     assetSynced = Signal()
 
-    def __init__(self, project, column_count=4, parent=None):
+    def __init__(self, project, column_count=4, show_context_menu=False, parent=None):
         super(AssetsViewer, self).__init__(parent=parent)
 
         self.setEditTriggers(QAbstractItemView.NoEditTriggers)
@@ -49,25 +50,51 @@ class AssetsViewer(grid.GridWidget, object):
         self.setSelectionMode(QAbstractItemView.NoSelection)
 
         self._assets = list()
-        self._project = project
+        self._cache = list()
 
-    def get_assets(self, category=None):
+        self._project = project
+        self._show_context_menu = show_context_menu
+
+        self._menu = self._create_contextual_menu()
+
+    def contextMenuEvent(self, event):
+        if not self._menu or not self._show_context_menu:
+            return
+        self._menu.exec_(event.globalPos())
+
+    def get_assets(self, update_cache=True, force=False):
         """
-        Returns a list with all the assets of the given categories; All assets will be returned if not category
-        is given
-        :param category: str
+        Returns a list with all the assets of the project
+        :param update_cache: bool, Updates the internal cache
+        :param force: bool, If True, cache and assets will be updated
         :return: list(ArtellaAssetWidget)
         """
 
-        if not self._assets:
-            self.update_assets()
+        if update_cache:
+            self.update_cache(force=force)
+
+        if self._assets and not force:
+            return self._assets
+
+        self.update_assets()
 
         return self._assets
 
-    def update_assets(self):
+    def update_cache(self, force=False):
+        """
+        Updates internal cache with the current assets located in Artella server
+        """
+
+        if self._cache and not force:
+            return self._cache
+
+        python.clear_list(self._cache)
+        return artellapipe.AssetsMgr().find_all_assets()
+
+    def update_assets(self, force=False):
         """
         Updates the list of assets in the asset viewer
-        :param async: bool, Whether the update operation should be done asynchronously or not
+        :param force: bool
         """
 
         if not self._project:
@@ -76,7 +103,7 @@ class AssetsViewer(grid.GridWidget, object):
 
         self.clear_assets()
 
-        all_assets = artellapipe.AssetsMgr().find_all_assets()
+        all_assets = self.update_cache(force=force)
         if not all_assets:
             return
 
@@ -100,7 +127,7 @@ class AssetsViewer(grid.GridWidget, object):
         Clear all the assets of the asset viewer
         """
 
-        self._assets = list()
+        python.clear_list(self._assets)
         self.clear()
 
     def change_category(self, category=None):
@@ -112,7 +139,7 @@ class AssetsViewer(grid.GridWidget, object):
         if not category:
             category = defines.ArtellaFileStatus.ALL
 
-        if category != defines.ArtellaFileStatus.ALL and category not in artellapipe.AssetsMgr().config.get('types'):
+        if category != defines.ArtellaFileStatus.ALL and category not in artellapipe.AssetsMgr().get_asset_categories():
             LOGGER.warning(
                 'Asset Type {} is not a valid asset type for project {}'.format(category, self._project.name.title()))
             category = defines.ArtellaFileStatus.ALL
@@ -137,11 +164,11 @@ class AssetsViewer(grid.GridWidget, object):
 
     def add_asset(self, asset_widget):
         """
-        Adds given asset to viewer
+        Adds given asset widget to viewer
         :param asset_widget: ArtellaAssetWidget
         """
 
-        if asset_widget is None:
+        if not asset_widget:
             return
 
         self._add_widget(asset_widget)
@@ -162,13 +189,34 @@ class AssetsViewer(grid.GridWidget, object):
         self.addWidget(row, col, widget)
         self.resizeRowsToContents()
 
+    def _create_contextual_menu(self):
+        """
+        Returns custom contextual menu
+        :return: QMenu
+        """
+
+        new_menu = QMenu(self)
+        get_thumbnails_action = QAction(tpDcc.ResourcesMgr().icon('picture'), 'Update Thumbnails', new_menu)
+        get_thumbnails_action.triggered.connect(self._on_update_thumbnails)
+        new_menu.addAction(get_thumbnails_action)
+
+        return new_menu
+
+    def _on_update_thumbnails(self):
+        """
+        Internal callback function that is called when Update Thumbnails action is triggered
+        """
+
+        self.update_assets_thumbnails(force=True)
+
 
 class CategorizedAssetViewer(base.BaseWidget, object):
 
-    def __init__(self, project, column_count=4, parent=None):
+    def __init__(self, project, column_count=4, show_context_menu=False, parent=None):
 
         self._project = project
         self._column_count = column_count
+        self._show_context_menu = show_context_menu
 
         super(CategorizedAssetViewer, self).__init__(parent=parent)
 
@@ -180,6 +228,7 @@ class CategorizedAssetViewer(base.BaseWidget, object):
         self._assets_viewer = artellapipe.AssetsViewer(
             project=self._project,
             column_count=self._column_count,
+            show_context_menu=self._show_context_menu,
             parent=self
         )
         self._assets_viewer.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
@@ -214,12 +263,12 @@ class CategorizedAssetViewer(base.BaseWidget, object):
         for category in all_asset_categories:
             new_btn = QPushButton(category)
             new_btn.setMinimumWidth(QFontMetrics(new_btn.font()).width(category) + 10)
-            new_btn.setIcon(resource.ResourceManager().icon(category.lower()))
+            new_btn.setIcon(tpDcc.ResourcesMgr().icon(category.lower()))
             new_btn.setCheckable(True)
             self._categories_menu_layout.addWidget(new_btn)
             self._categories_btn_grp.addButton(new_btn)
             if category == defines.ArtellaFileStatus.ALL:
-                new_btn.setIcon(resource.ResourceManager().icon('home'))
+                new_btn.setIcon(tpDcc.ResourcesMgr().icon('home'))
                 new_btn.setChecked(True)
             new_btn.toggled.connect(partial(self._on_change_category, category))
 
@@ -227,6 +276,7 @@ class CategorizedAssetViewer(base.BaseWidget, object):
         """
         Internal callback function that is called when the user presses an Asset Category button
         :param category: str
+        :param flag: bool
         """
 
         if flag:
